# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/cloud_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/inventory/v1/cloud_service.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"C\n\x15\x43loudServiceReference\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rexternal_link\x18\x02 \x01(\t\"\xbe\x03\n\x14\x43reateServiceRequest\x12\x1a\n\x12\x63loud_service_type\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x15\n\rinstance_size\x18\x07 \x01(\x02\x12\x14\n\x0cip_addresses\x18\n \x03(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\treference\x18\r \x01(\x0b\x32\x30.spaceone.api.inventory.v1.CloudServiceReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bregion_code\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\"\xc3\x03\n\x19UpdateCloudServiceRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\x12\x15\n\rinstance_type\x18\x04 \x01(\t\x12\x15\n\rinstance_size\x18\x05 \x01(\x02\x12\x14\n\x0cip_addresses\x18\x06 \x03(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\treference\x18\r \x01(\x0b\x32\x30.spaceone.api.inventory.v1.CloudServiceReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bregion_code\x18\x14 \x01(\t\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\x12\x17\n\x0frelease_project\x18\x1e \x01(\x08\x12\x16\n\x0erelease_region\x18\x1f \x01(\x08\"W\n\x1aPinCloudServiceDataRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"B\n\x13\x43loudServiceRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x16GetCloudServiceRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xee\x02\n\x11\x43loudServiceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63loud_service_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x13\n\x0bregion_code\x18\n \x01(\t\x12\x12\n\nip_address\x18\x0b \x01(\t\x12\x19\n\x11resource_group_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\"\xd1\x04\n\x10\x43loudServiceInfo\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x15\n\rinstance_type\x18\x05 \x01(\t\x12\x15\n\rinstance_size\x18\x06 \x01(\x02\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\treference\x18\r \x01(\x0b\x32\x30.spaceone.api.inventory.v1.CloudServiceReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x63ollection_info\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cip_addresses\x18\x11 \x03(\t\x12\x13\n\x0bregion_code\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\x12\x12\n\ndeleted_at\x18! \x01(\t\"f\n\x11\x43loudServicesInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.inventory.v1.CloudServiceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x97\x01\n\x15\x43loudServiceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1a\n\x12\x61llow_delete_state\x18\x04 \x01(\x08\x32\xb7\x08\n\x0c\x43loudService\x12\x8c\x01\n\x06\x63reate\x12/.spaceone.api.inventory.v1.CreateServiceRequest\x1a+.spaceone.api.inventory.v1.CloudServiceInfo\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/inventory/v1/cloud-services\x12\xa3\x01\n\x06update\x12\x34.spaceone.api.inventory.v1.UpdateCloudServiceRequest\x1a+.spaceone.api.inventory.v1.CloudServiceInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./inventory/v1/cloud-service/{cloud_service_id}\x12\x88\x01\n\x06\x64\x65lete\x12..spaceone.api.inventory.v1.CloudServiceRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30*./inventory/v1/cloud-service/{cloud_service_id}\x12\x9d\x01\n\x03get\x12\x31.spaceone.api.inventory.v1.GetCloudServiceRequest\x1a+.spaceone.api.inventory.v1.CloudServiceInfo\"6\x82\xd3\xe4\x93\x02\x30\x12./inventory/v1/cloud-service/{cloud_service_id}\x12\xaf\x01\n\x04list\x12,.spaceone.api.inventory.v1.CloudServiceQuery\x1a,.spaceone.api.inventory.v1.CloudServicesInfo\"K\x82\xd3\xe4\x93\x02\x45\x12\x1c/inventory/v1/cloud-servicesZ%\"#/inventory/v1/cloud-services/search\x12|\n\x04stat\x12\x30.spaceone.api.inventory.v1.CloudServiceStatQuery\x1a\x17.google.protobuf.Struct\")\x82\xd3\xe4\x93\x02#\"!/inventory/v1/cloud-services/stat\x12\x96\x01\n\x11\x61llow_delete_stat\x12\x30.spaceone.api.inventory.v1.CloudServiceStatQuery\x1a\x17.google.protobuf.Struct\"6\x82\xd3\xe4\x93\x02\x30\"./inventory/v1/cloud-services/allow_delete_statb\x06proto3')



_CLOUDSERVICEREFERENCE = DESCRIPTOR.message_types_by_name['CloudServiceReference']
_CREATESERVICEREQUEST = DESCRIPTOR.message_types_by_name['CreateServiceRequest']
_UPDATECLOUDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['UpdateCloudServiceRequest']
_PINCLOUDSERVICEDATAREQUEST = DESCRIPTOR.message_types_by_name['PinCloudServiceDataRequest']
_CLOUDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['CloudServiceRequest']
_GETCLOUDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['GetCloudServiceRequest']
_CLOUDSERVICEQUERY = DESCRIPTOR.message_types_by_name['CloudServiceQuery']
_CLOUDSERVICEINFO = DESCRIPTOR.message_types_by_name['CloudServiceInfo']
_CLOUDSERVICESINFO = DESCRIPTOR.message_types_by_name['CloudServicesInfo']
_CLOUDSERVICESTATQUERY = DESCRIPTOR.message_types_by_name['CloudServiceStatQuery']
CloudServiceReference = _reflection.GeneratedProtocolMessageType('CloudServiceReference', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEREFERENCE,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceReference)
  })
_sym_db.RegisterMessage(CloudServiceReference)

CreateServiceRequest = _reflection.GeneratedProtocolMessageType('CreateServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateServiceRequest)
  })
_sym_db.RegisterMessage(CreateServiceRequest)

UpdateCloudServiceRequest = _reflection.GeneratedProtocolMessageType('UpdateCloudServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLOUDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateCloudServiceRequest)
  })
_sym_db.RegisterMessage(UpdateCloudServiceRequest)

PinCloudServiceDataRequest = _reflection.GeneratedProtocolMessageType('PinCloudServiceDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINCLOUDSERVICEDATAREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PinCloudServiceDataRequest)
  })
_sym_db.RegisterMessage(PinCloudServiceDataRequest)

CloudServiceRequest = _reflection.GeneratedProtocolMessageType('CloudServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceRequest)
  })
_sym_db.RegisterMessage(CloudServiceRequest)

GetCloudServiceRequest = _reflection.GeneratedProtocolMessageType('GetCloudServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCloudServiceRequest)
  })
_sym_db.RegisterMessage(GetCloudServiceRequest)

CloudServiceQuery = _reflection.GeneratedProtocolMessageType('CloudServiceQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceQuery)
  })
_sym_db.RegisterMessage(CloudServiceQuery)

CloudServiceInfo = _reflection.GeneratedProtocolMessageType('CloudServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceInfo)
  })
_sym_db.RegisterMessage(CloudServiceInfo)

CloudServicesInfo = _reflection.GeneratedProtocolMessageType('CloudServicesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICESINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServicesInfo)
  })
_sym_db.RegisterMessage(CloudServicesInfo)

CloudServiceStatQuery = _reflection.GeneratedProtocolMessageType('CloudServiceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceStatQuery)
  })
_sym_db.RegisterMessage(CloudServiceStatQuery)

_CLOUDSERVICE = DESCRIPTOR.services_by_name['CloudService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDSERVICE.methods_by_name['create']._options = None
  _CLOUDSERVICE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\036\"\034/inventory/v1/cloud-services'
  _CLOUDSERVICE.methods_by_name['update']._options = None
  _CLOUDSERVICE.methods_by_name['update']._serialized_options = b'\202\323\344\223\0020\032./inventory/v1/cloud-service/{cloud_service_id}'
  _CLOUDSERVICE.methods_by_name['delete']._options = None
  _CLOUDSERVICE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0020*./inventory/v1/cloud-service/{cloud_service_id}'
  _CLOUDSERVICE.methods_by_name['get']._options = None
  _CLOUDSERVICE.methods_by_name['get']._serialized_options = b'\202\323\344\223\0020\022./inventory/v1/cloud-service/{cloud_service_id}'
  _CLOUDSERVICE.methods_by_name['list']._options = None
  _CLOUDSERVICE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002E\022\034/inventory/v1/cloud-servicesZ%\"#/inventory/v1/cloud-services/search'
  _CLOUDSERVICE.methods_by_name['stat']._options = None
  _CLOUDSERVICE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002#\"!/inventory/v1/cloud-services/stat'
  _CLOUDSERVICE.methods_by_name['allow_delete_stat']._options = None
  _CLOUDSERVICE.methods_by_name['allow_delete_stat']._serialized_options = b'\202\323\344\223\0020\"./inventory/v1/cloud-services/allow_delete_stat'
  _CLOUDSERVICEREFERENCE._serialized_start=199
  _CLOUDSERVICEREFERENCE._serialized_end=266
  _CREATESERVICEREQUEST._serialized_start=269
  _CREATESERVICEREQUEST._serialized_end=715
  _UPDATECLOUDSERVICEREQUEST._serialized_start=718
  _UPDATECLOUDSERVICEREQUEST._serialized_end=1169
  _PINCLOUDSERVICEDATAREQUEST._serialized_start=1171
  _PINCLOUDSERVICEDATAREQUEST._serialized_end=1258
  _CLOUDSERVICEREQUEST._serialized_start=1260
  _CLOUDSERVICEREQUEST._serialized_end=1326
  _GETCLOUDSERVICEREQUEST._serialized_start=1328
  _GETCLOUDSERVICEREQUEST._serialized_end=1411
  _CLOUDSERVICEQUERY._serialized_start=1414
  _CLOUDSERVICEQUERY._serialized_end=1780
  _CLOUDSERVICEINFO._serialized_start=1783
  _CLOUDSERVICEINFO._serialized_end=2376
  _CLOUDSERVICESINFO._serialized_start=2378
  _CLOUDSERVICESINFO._serialized_end=2480
  _CLOUDSERVICESTATQUERY._serialized_start=2483
  _CLOUDSERVICESTATQUERY._serialized_end=2634
  _CLOUDSERVICE._serialized_start=2637
  _CLOUDSERVICE._serialized_end=3716
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/monitoring/v1/alert.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"I\n\rAlertResource\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"<\n\x0e\x41lertResponder\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"8\n\x0c\x41lertAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\"\xac\x01\n\x12\x43reateAlertRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x61ssignee\x18\x03 \x01(\t\x12\x39\n\x07urgency\x18\x04 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xb6\x02\n\x12UpdateAlertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x16\n\x0estatus_message\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08\x61ssignee\x18\x06 \x01(\t\x12\x39\n\x07urgency\x18\x07 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x1c\n\x14reset_status_message\x18\x0b \x01(\x08\x12\x19\n\x11reset_description\x18\x0c \x01(\x08\x12\x16\n\x0ereset_assignee\x18\r \x01(\x08\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"N\n\x17UpdateAlertStateRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x12\n\naccess_key\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\"H\n\x11MergeAlertRequest\x12\x0e\n\x06\x61lerts\x18\x01 \x03(\t\x12\x10\n\x08merge_to\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"K\n\x12SnoozeAlertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"h\n\x15\x41lertResponderRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"X\n\x1d\x41lertProjectDependencyRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"3\n\x0c\x41lertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"D\n\x0fGetAlertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc0\x03\n\nAlertQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x14\n\x0c\x61lert_number\x18\x02 \x01(\x05\x12\x10\n\x08\x61lert_id\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x35\n\x05state\x18\x05 \x01(\x0e\x32&.spaceone.api.monitoring.v1.AlertState\x12\x10\n\x08\x61ssignee\x18\x06 \x01(\t\x12\x39\n\x07urgency\x18\x07 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x10\n\x08severity\x18\x08 \x01(\t\x12\x12\n\nis_snoozed\x18\t \x01(\t\x12\x13\n\x0bresource_id\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x0c \x01(\t\x12\x14\n\x0ctriggered_by\x18\r \x01(\t\x12\x12\n\nwebhook_id\x18\x15 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x16 \x01(\t\x12\x12\n\nproject_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\"\xa2\x08\n\tAlertInfo\x12\x14\n\x0c\x61lert_number\x18\x01 \x01(\x05\x12\x10\n\x08\x61lert_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.spaceone.api.monitoring.v1.AlertState\x12\x16\n\x0estatus_message\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08\x61ssignee\x18\x07 \x01(\t\x12\x39\n\x07urgency\x18\x08 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x10\n\x08severity\x18\t \x01(\t\x12\x0c\n\x04rule\x18\n \x01(\t\x12;\n\x08resource\x18\x0b \x01(\x0b\x32).spaceone.api.monitoring.v1.AlertResource\x12\x10\n\x08provider\x18\x0c \x01(\t\x12\x39\n\x07\x61\x63\x63ount\x18\r \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertAccount\x12\x12\n\nis_snoozed\x18\x0e \x01(\x08\x12\x18\n\x10snoozed_end_time\x18\x0f \x01(\t\x12\x17\n\x0f\x65scalation_step\x18\x10 \x01(\x05\x12\x16\n\x0e\x65scalation_ttl\x18\x11 \x01(\x05\x12>\n\nresponders\x18\x12 \x03(\x0b\x32*.spaceone.api.monitoring.v1.AlertResponder\x12\x1c\n\x14project_dependencies\x18\x13 \x03(\t\x12\x11\n\timage_url\x18\x14 \x01(\t\x12\x30\n\x0f\x61\x64\x64itional_info\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0ctriggered_by\x18\x1f \x01(\t\x12\x12\n\nwebhook_id\x18  \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18! \x01(\t\x12\x12\n\nproject_id\x18\" \x01(\t\x12\x11\n\tdomain_id\x18# \x01(\t\x12\x12\n\ncreated_at\x18) \x01(\t\x12\x12\n\nupdated_at\x18* \x01(\t\x12\x17\n\x0f\x61\x63knowledged_at\x18+ \x01(\t\x12\x13\n\x0bresolved_at\x18, \x01(\t\x12\x14\n\x0c\x65scalated_at\x18- \x01(\t\x12\x14\n\x0cservice_name\x18. \x01(\t\x12\x11\n\thost_name\x18/ \x01(\t\x12\n\n\x02ip\x18\x30 \x01(\t\x12\x15\n\rreal_time_log\x18\x31 \x01(\t\x12\x15\n\rlast_error_at\x18\x32 \x01(\t\x12\x18\n\x10\x61lert_number_str\x18\x33 \x01(\t\x12)\n\x08raw_data\x18\x34 \x01(\x0b\x32\x17.google.protobuf.Struct\"Y\n\nAlertsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.monitoring.v1.AlertInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Y\n\x0e\x41lertStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*9\n\x0c\x41lertUrgency\x12\x16\n\x12\x41LERT_URGENCY_NONE\x10\x00\x12\x08\n\x04HIGH\x10\x01\x12\x07\n\x03LOW\x10\x02*h\n\nAlertState\x12\x14\n\x10\x41LERT_STATE_NONE\x10\x00\x12\r\n\tTRIGGERED\x10\x01\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x02\x12\x0c\n\x08RESOLVED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\n\n\x06PUSHED\x10\x05\x32\x9e\x0f\n\x05\x41lert\x12~\n\x06\x63reate\x12..spaceone.api.monitoring.v1.CreateAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/monitoring/v1/alerts\x12\x88\x01\n\x06update\x12..spaceone.api.monitoring.v1.UpdateAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/monitoring/v1/alert/{alert_id}\x12\xa8\x01\n\x0cupdate_state\x12\x33.spaceone.api.monitoring.v1.UpdateAlertStateRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"<\x82\xd3\xe4\x93\x02\x36\"4/monitoring/v1/alert/{alert_id}/{access_key}/{state}\x12\x82\x01\n\x05merge\x12-.spaceone.api.monitoring.v1.MergeAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/monitoring/v1/alerts/merge\x12\x8f\x01\n\x06snooze\x12..spaceone.api.monitoring.v1.SnoozeAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\".\x82\xd3\xe4\x93\x02(\"&/monitoring/v1/alert/{alert_id}/snooze\x12\x9d\x01\n\radd_responder\x12\x31.spaceone.api.monitoring.v1.AlertResponderRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"2\x82\xd3\xe4\x93\x02,\"*/monitoring/v1/alert/{alert_id}/responders\x12\xa0\x01\n\x10remove_responder\x12\x31.spaceone.api.monitoring.v1.AlertResponderRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"2\x82\xd3\xe4\x93\x02,**/monitoring/v1/alert/{alert_id}/responders\x12\xb8\x01\n\x16\x61\x64\x64_project_dependency\x12\x39.spaceone.api.monitoring.v1.AlertProjectDependencyRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"<\x82\xd3\xe4\x93\x02\x36\"4/monitoring/v1/alert/{alert_id}/project-dependencies\x12\xc6\x01\n\x19remove_project_dependency\x12\x39.spaceone.api.monitoring.v1.AlertProjectDependencyRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"G\x82\xd3\xe4\x93\x02\x41*?/monitoring/v1/alert/{alert_id}/project-dependency/{project_id}\x12s\n\x06\x64\x65lete\x12(.spaceone.api.monitoring.v1.AlertRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/monitoring/v1/alert/{alert_id}\x12\x82\x01\n\x03get\x12+.spaceone.api.monitoring.v1.GetAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/monitoring/v1/alert/{alert_id}\x12\x95\x01\n\x04list\x12&.spaceone.api.monitoring.v1.AlertQuery\x1a&.spaceone.api.monitoring.v1.AlertsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/monitoring/v1/alertsZ\x1e\"\x1c/monitoring/v1/alerts/search\x12o\n\x04stat\x12*.spaceone.api.monitoring.v1.AlertStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/monitoring/v1/alerts/statb\x06proto3')

_ALERTURGENCY = DESCRIPTOR.enum_types_by_name['AlertUrgency']
AlertUrgency = enum_type_wrapper.EnumTypeWrapper(_ALERTURGENCY)
_ALERTSTATE = DESCRIPTOR.enum_types_by_name['AlertState']
AlertState = enum_type_wrapper.EnumTypeWrapper(_ALERTSTATE)
ALERT_URGENCY_NONE = 0
HIGH = 1
LOW = 2
ALERT_STATE_NONE = 0
TRIGGERED = 1
ACKNOWLEDGED = 2
RESOLVED = 3
ERROR = 4
PUSHED = 5


_ALERTRESOURCE = DESCRIPTOR.message_types_by_name['AlertResource']
_ALERTRESPONDER = DESCRIPTOR.message_types_by_name['AlertResponder']
_ALERTACCOUNT = DESCRIPTOR.message_types_by_name['AlertAccount']
_CREATEALERTREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertRequest']
_UPDATEALERTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertRequest']
_UPDATEALERTSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertStateRequest']
_MERGEALERTREQUEST = DESCRIPTOR.message_types_by_name['MergeAlertRequest']
_SNOOZEALERTREQUEST = DESCRIPTOR.message_types_by_name['SnoozeAlertRequest']
_ALERTRESPONDERREQUEST = DESCRIPTOR.message_types_by_name['AlertResponderRequest']
_ALERTPROJECTDEPENDENCYREQUEST = DESCRIPTOR.message_types_by_name['AlertProjectDependencyRequest']
_ALERTREQUEST = DESCRIPTOR.message_types_by_name['AlertRequest']
_GETALERTREQUEST = DESCRIPTOR.message_types_by_name['GetAlertRequest']
_ALERTQUERY = DESCRIPTOR.message_types_by_name['AlertQuery']
_ALERTINFO = DESCRIPTOR.message_types_by_name['AlertInfo']
_ALERTSINFO = DESCRIPTOR.message_types_by_name['AlertsInfo']
_ALERTSTATQUERY = DESCRIPTOR.message_types_by_name['AlertStatQuery']
AlertResource = _reflection.GeneratedProtocolMessageType('AlertResource', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESOURCE,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertResource)
  })
_sym_db.RegisterMessage(AlertResource)

AlertResponder = _reflection.GeneratedProtocolMessageType('AlertResponder', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONDER,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertResponder)
  })
_sym_db.RegisterMessage(AlertResponder)

AlertAccount = _reflection.GeneratedProtocolMessageType('AlertAccount', (_message.Message,), {
  'DESCRIPTOR' : _ALERTACCOUNT,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertAccount)
  })
_sym_db.RegisterMessage(AlertAccount)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

UpdateAlertStateRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTSTATEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateAlertStateRequest)
  })
_sym_db.RegisterMessage(UpdateAlertStateRequest)

MergeAlertRequest = _reflection.GeneratedProtocolMessageType('MergeAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _MERGEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MergeAlertRequest)
  })
_sym_db.RegisterMessage(MergeAlertRequest)

SnoozeAlertRequest = _reflection.GeneratedProtocolMessageType('SnoozeAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.SnoozeAlertRequest)
  })
_sym_db.RegisterMessage(SnoozeAlertRequest)

AlertResponderRequest = _reflection.GeneratedProtocolMessageType('AlertResponderRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONDERREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertResponderRequest)
  })
_sym_db.RegisterMessage(AlertResponderRequest)

AlertProjectDependencyRequest = _reflection.GeneratedProtocolMessageType('AlertProjectDependencyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTPROJECTDEPENDENCYREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertProjectDependencyRequest)
  })
_sym_db.RegisterMessage(AlertProjectDependencyRequest)

AlertRequest = _reflection.GeneratedProtocolMessageType('AlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertRequest)
  })
_sym_db.RegisterMessage(AlertRequest)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

AlertQuery = _reflection.GeneratedProtocolMessageType('AlertQuery', (_message.Message,), {
  'DESCRIPTOR' : _ALERTQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertQuery)
  })
_sym_db.RegisterMessage(AlertQuery)

AlertInfo = _reflection.GeneratedProtocolMessageType('AlertInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINFO,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertInfo)
  })
_sym_db.RegisterMessage(AlertInfo)

AlertsInfo = _reflection.GeneratedProtocolMessageType('AlertsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALERTSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertsInfo)
  })
_sym_db.RegisterMessage(AlertsInfo)

AlertStatQuery = _reflection.GeneratedProtocolMessageType('AlertStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ALERTSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertStatQuery)
  })
_sym_db.RegisterMessage(AlertStatQuery)

_ALERT = DESCRIPTOR.services_by_name['Alert']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ALERT.methods_by_name['create']._options = None
  _ALERT.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/monitoring/v1/alerts'
  _ALERT.methods_by_name['update']._options = None
  _ALERT.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/monitoring/v1/alert/{alert_id}'
  _ALERT.methods_by_name['update_state']._options = None
  _ALERT.methods_by_name['update_state']._serialized_options = b'\202\323\344\223\0026\"4/monitoring/v1/alert/{alert_id}/{access_key}/{state}'
  _ALERT.methods_by_name['merge']._options = None
  _ALERT.methods_by_name['merge']._serialized_options = b'\202\323\344\223\002\035\"\033/monitoring/v1/alerts/merge'
  _ALERT.methods_by_name['snooze']._options = None
  _ALERT.methods_by_name['snooze']._serialized_options = b'\202\323\344\223\002(\"&/monitoring/v1/alert/{alert_id}/snooze'
  _ALERT.methods_by_name['add_responder']._options = None
  _ALERT.methods_by_name['add_responder']._serialized_options = b'\202\323\344\223\002,\"*/monitoring/v1/alert/{alert_id}/responders'
  _ALERT.methods_by_name['remove_responder']._options = None
  _ALERT.methods_by_name['remove_responder']._serialized_options = b'\202\323\344\223\002,**/monitoring/v1/alert/{alert_id}/responders'
  _ALERT.methods_by_name['add_project_dependency']._options = None
  _ALERT.methods_by_name['add_project_dependency']._serialized_options = b'\202\323\344\223\0026\"4/monitoring/v1/alert/{alert_id}/project-dependencies'
  _ALERT.methods_by_name['remove_project_dependency']._options = None
  _ALERT.methods_by_name['remove_project_dependency']._serialized_options = b'\202\323\344\223\002A*?/monitoring/v1/alert/{alert_id}/project-dependency/{project_id}'
  _ALERT.methods_by_name['delete']._options = None
  _ALERT.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/monitoring/v1/alert/{alert_id}'
  _ALERT.methods_by_name['get']._options = None
  _ALERT.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/monitoring/v1/alert/{alert_id}'
  _ALERT.methods_by_name['list']._options = None
  _ALERT.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/monitoring/v1/alertsZ\036\"\034/monitoring/v1/alerts/search'
  _ALERT.methods_by_name['stat']._options = None
  _ALERT.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/monitoring/v1/alerts/stat'
  _ALERTURGENCY._serialized_start=3120
  _ALERTURGENCY._serialized_end=3177
  _ALERTSTATE._serialized_start=3179
  _ALERTSTATE._serialized_end=3283
  _ALERTRESOURCE._serialized_start=193
  _ALERTRESOURCE._serialized_end=266
  _ALERTRESPONDER._serialized_start=268
  _ALERTRESPONDER._serialized_end=328
  _ALERTACCOUNT._serialized_start=330
  _ALERTACCOUNT._serialized_end=386
  _CREATEALERTREQUEST._serialized_start=389
  _CREATEALERTREQUEST._serialized_end=561
  _UPDATEALERTREQUEST._serialized_start=564
  _UPDATEALERTREQUEST._serialized_end=874
  _UPDATEALERTSTATEREQUEST._serialized_start=876
  _UPDATEALERTSTATEREQUEST._serialized_end=954
  _MERGEALERTREQUEST._serialized_start=956
  _MERGEALERTREQUEST._serialized_end=1028
  _SNOOZEALERTREQUEST._serialized_start=1030
  _SNOOZEALERTREQUEST._serialized_end=1105
  _ALERTRESPONDERREQUEST._serialized_start=1107
  _ALERTRESPONDERREQUEST._serialized_end=1211
  _ALERTPROJECTDEPENDENCYREQUEST._serialized_start=1213
  _ALERTPROJECTDEPENDENCYREQUEST._serialized_end=1301
  _ALERTREQUEST._serialized_start=1303
  _ALERTREQUEST._serialized_end=1354
  _GETALERTREQUEST._serialized_start=1356
  _GETALERTREQUEST._serialized_end=1424
  _ALERTQUERY._serialized_start=1427
  _ALERTQUERY._serialized_end=1875
  _ALERTINFO._serialized_start=1878
  _ALERTINFO._serialized_end=2936
  _ALERTSINFO._serialized_start=2938
  _ALERTSINFO._serialized_end=3027
  _ALERTSTATQUERY._serialized_start=3029
  _ALERTSTATQUERY._serialized_end=3118
  _ALERT._serialized_start=3286
  _ALERT._serialized_end=5236
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/role_binding.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import project_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2
from spaceone.api.identity.v1 import project_group_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__group__pb2
from spaceone.api.identity.v1 import role_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/identity/v1/role_binding.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a&spaceone/api/identity/v1/project.proto\x1a,spaceone/api/identity/v1/project_group.proto\x1a#spaceone/api/identity/v1/role.proto\"\xeb\x01\n\x18\x43reateRoleBindingRequest\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x0f\n\x07role_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x18\n\x10project_group_id\x18\x05 \x01(\t\x12*\n\x06labels\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x08 \x01(\t\"\x99\x01\n\x18UpdateRoleBindingRequest\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12*\n\x06labels\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"@\n\x12RoleBindingRequest\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Q\n\x15GetRoleBindingRequest\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8c\x03\n\x0fRoleBindingInfo\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x35\n\trole_info\x18\x04 \x01(\x0b\x32\".spaceone.api.identity.v1.RoleInfo\x12;\n\x0cproject_info\x18\x05 \x01(\x0b\x32%.spaceone.api.identity.v1.ProjectInfo\x12\x46\n\x12project_group_info\x18\x06 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12*\n\x06labels\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"\xe8\x01\n\x10RoleBindingQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x17\n\x0frole_binding_id\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x0f\n\x07role_id\x18\x05 \x01(\t\x12\x11\n\trole_type\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x18\n\x10project_group_id\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\"c\n\x10RoleBindingsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.identity.v1.RoleBindingInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14RoleBindingStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf8\x06\n\x0bRoleBinding\x12\x8b\x01\n\x06\x63reate\x12\x32.spaceone.api.identity.v1.CreateRoleBindingRequest\x1a).spaceone.api.identity.v1.RoleBindingInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/role-bindings\x12\x9d\x01\n\x06update\x12\x32.spaceone.api.identity.v1.UpdateRoleBindingRequest\x1a).spaceone.api.identity.v1.RoleBindingInfo\"4\x82\xd3\xe4\x93\x02.\x1a,/identity/v1/role-bindings/{role_binding_id}\x12\x84\x01\n\x06\x64\x65lete\x12,.spaceone.api.identity.v1.RoleBindingRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.*,/identity/v1/role-bindings/{role_binding_id}\x12\x97\x01\n\x03get\x12/.spaceone.api.identity.v1.GetRoleBindingRequest\x1a).spaceone.api.identity.v1.RoleBindingInfo\"4\x82\xd3\xe4\x93\x02.\x12,/identity/v1/role-bindings/{role_binding_id}\x12\xa7\x01\n\x04list\x12*.spaceone.api.identity.v1.RoleBindingQuery\x1a*.spaceone.api.identity.v1.RoleBindingsInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/identity/v1/role-bindingsZ#\"!/identity/v1/role-bindings/search\x12p\n\x04stat\x12..spaceone.api.identity.v1.RoleBindingStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/identity/v1/roles/statb\x06proto3')



_CREATEROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['CreateRoleBindingRequest']
_UPDATEROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['UpdateRoleBindingRequest']
_ROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['RoleBindingRequest']
_GETROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['GetRoleBindingRequest']
_ROLEBINDINGINFO = DESCRIPTOR.message_types_by_name['RoleBindingInfo']
_ROLEBINDINGQUERY = DESCRIPTOR.message_types_by_name['RoleBindingQuery']
_ROLEBINDINGSINFO = DESCRIPTOR.message_types_by_name['RoleBindingsInfo']
_ROLEBINDINGSTATQUERY = DESCRIPTOR.message_types_by_name['RoleBindingStatQuery']
CreateRoleBindingRequest = _reflection.GeneratedProtocolMessageType('CreateRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateRoleBindingRequest)
  })
_sym_db.RegisterMessage(CreateRoleBindingRequest)

UpdateRoleBindingRequest = _reflection.GeneratedProtocolMessageType('UpdateRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateRoleBindingRequest)
  })
_sym_db.RegisterMessage(UpdateRoleBindingRequest)

RoleBindingRequest = _reflection.GeneratedProtocolMessageType('RoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingRequest)
  })
_sym_db.RegisterMessage(RoleBindingRequest)

GetRoleBindingRequest = _reflection.GeneratedProtocolMessageType('GetRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetRoleBindingRequest)
  })
_sym_db.RegisterMessage(GetRoleBindingRequest)

RoleBindingInfo = _reflection.GeneratedProtocolMessageType('RoleBindingInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGINFO,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingInfo)
  })
_sym_db.RegisterMessage(RoleBindingInfo)

RoleBindingQuery = _reflection.GeneratedProtocolMessageType('RoleBindingQuery', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGQUERY,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingQuery)
  })
_sym_db.RegisterMessage(RoleBindingQuery)

RoleBindingsInfo = _reflection.GeneratedProtocolMessageType('RoleBindingsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGSINFO,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingsInfo)
  })
_sym_db.RegisterMessage(RoleBindingsInfo)

RoleBindingStatQuery = _reflection.GeneratedProtocolMessageType('RoleBindingStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingStatQuery)
  })
_sym_db.RegisterMessage(RoleBindingStatQuery)

_ROLEBINDING = DESCRIPTOR.services_by_name['RoleBinding']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLEBINDING.methods_by_name['create']._options = None
  _ROLEBINDING.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/role-bindings'
  _ROLEBINDING.methods_by_name['update']._options = None
  _ROLEBINDING.methods_by_name['update']._serialized_options = b'\202\323\344\223\002.\032,/identity/v1/role-bindings/{role_binding_id}'
  _ROLEBINDING.methods_by_name['delete']._options = None
  _ROLEBINDING.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002.*,/identity/v1/role-bindings/{role_binding_id}'
  _ROLEBINDING.methods_by_name['get']._options = None
  _ROLEBINDING.methods_by_name['get']._serialized_options = b'\202\323\344\223\002.\022,/identity/v1/role-bindings/{role_binding_id}'
  _ROLEBINDING.methods_by_name['list']._options = None
  _ROLEBINDING.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/identity/v1/role-bindingsZ#\"!/identity/v1/role-bindings/search'
  _ROLEBINDING.methods_by_name['stat']._options = None
  _ROLEBINDING.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/identity/v1/roles/stat'
  _CREATEROLEBINDINGREQUEST._serialized_start=320
  _CREATEROLEBINDINGREQUEST._serialized_end=555
  _UPDATEROLEBINDINGREQUEST._serialized_start=558
  _UPDATEROLEBINDINGREQUEST._serialized_end=711
  _ROLEBINDINGREQUEST._serialized_start=713
  _ROLEBINDINGREQUEST._serialized_end=777
  _GETROLEBINDINGREQUEST._serialized_start=779
  _GETROLEBINDINGREQUEST._serialized_end=860
  _ROLEBINDINGINFO._serialized_start=863
  _ROLEBINDINGINFO._serialized_end=1259
  _ROLEBINDINGQUERY._serialized_start=1262
  _ROLEBINDINGQUERY._serialized_end=1494
  _ROLEBINDINGSINFO._serialized_start=1496
  _ROLEBINDINGSINFO._serialized_end=1595
  _ROLEBINDINGSTATQUERY._serialized_start=1597
  _ROLEBINDINGSTATQUERY._serialized_end=1692
  _ROLEBINDING._serialized_start=1695
  _ROLEBINDING._serialized_end=2583
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/event_rule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/monitoring/v1/event_rule.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"B\n\x12\x45ventRuleCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\"F\n\x18\x45ventRuleActionResponder\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"+\n\tMatchRule\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\"\xdd\x02\n\x10\x45ventRuleActions\x12\x17\n\x0f\x63hange_assignee\x18\x01 \x01(\t\x12\x16\n\x0e\x63hange_urgency\x18\x02 \x01(\t\x12\x16\n\x0e\x63hange_project\x18\x03 \x01(\t\x12\x1e\n\x16\x61\x64\x64_project_dependency\x18\x04 \x03(\t\x12K\n\radd_responder\x18\x05 \x03(\x0b\x32\x34.spaceone.api.monitoring.v1.EventRuleActionResponder\x12\x44\n\x15match_service_account\x18\x06 \x01(\x0b\x32%.spaceone.api.monitoring.v1.MatchRule\x12\x34\n\x13\x61\x64\x64_additional_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x17\n\x0fno_notification\x18\x08 \x01(\x08\"+\n\x10\x45ventRuleOptions\x12\x17\n\x0fstop_processing\x18\x01 \x01(\x08\"\xd2\x03\n\x16\x43reateEventRuleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\nconditions\x18\x02 \x03(\x0b\x32..spaceone.api.monitoring.v1.EventRuleCondition\x12^\n\x11\x63onditions_policy\x18\x03 \x01(\x0e\x32\x43.spaceone.api.monitoring.v1.CreateEventRuleRequest.ConditionsPolicy\x12=\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32,.spaceone.api.monitoring.v1.EventRuleActions\x12=\n\x07options\x18\x05 \x01(\x0b\x32,.spaceone.api.monitoring.v1.EventRuleOptions\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\":\n\x10\x43onditionsPolicy\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03\x41NY\x10\x02\x12\n\n\x06\x41LWAYS\x10\x03\"\xd5\x03\n\x16UpdateEventRuleRequest\x12\x15\n\revent_rule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\nconditions\x18\x03 \x03(\x0b\x32..spaceone.api.monitoring.v1.EventRuleCondition\x12^\n\x11\x63onditions_policy\x18\x04 \x01(\x0e\x32\x43.spaceone.api.monitoring.v1.UpdateEventRuleRequest.ConditionsPolicy\x12=\n\x07\x61\x63tions\x18\x05 \x01(\x0b\x32,.spaceone.api.monitoring.v1.EventRuleActions\x12=\n\x07options\x18\x06 \x01(\x0b\x32,.spaceone.api.monitoring.v1.EventRuleOptions\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\":\n\x10\x43onditionsPolicy\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03\x41NY\x10\x02\x12\n\n\x06\x41LWAYS\x10\x03\"V\n\x1b\x43hangeEventRuleOrderRequest\x12\x15\n\revent_rule_id\x18\x01 \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"<\n\x10\x45ventRuleRequest\x12\x15\n\revent_rule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"M\n\x13GetEventRuleRequest\x12\x15\n\revent_rule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8d\x02\n\x0e\x45ventRuleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x15\n\revent_rule_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x05scope\x18\x04 \x01(\x0e\x32\x39.spaceone.api.monitoring.v1.EventRuleQuery.EventRuleScope\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"9\n\x0e\x45ventRuleScope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06GLOBAL\x10\x01\x12\x0b\n\x07PROJECT\x10\x02\"\xfe\x04\n\rEventRuleInfo\x12\x15\n\revent_rule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x42\n\nconditions\x18\x04 \x03(\x0b\x32..spaceone.api.monitoring.v1.EventRuleCondition\x12U\n\x11\x63onditions_policy\x18\x05 \x01(\x0e\x32:.spaceone.api.monitoring.v1.EventRuleInfo.ConditionsPolicy\x12=\n\x07\x61\x63tions\x18\x06 \x01(\x0b\x32,.spaceone.api.monitoring.v1.EventRuleActions\x12=\n\x07options\x18\x07 \x01(\x0b\x32,.spaceone.api.monitoring.v1.EventRuleOptions\x12G\n\x05scope\x18\x08 \x01(\x0e\x32\x38.spaceone.api.monitoring.v1.EventRuleInfo.EventRuleScope\x12\x12\n\nproject_id\x18\t \x01(\t\x12%\n\x04tags\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"9\n\x0e\x45ventRuleScope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06GLOBAL\x10\x01\x12\x0b\n\x07PROJECT\x10\x02\":\n\x10\x43onditionsPolicy\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03\x41NY\x10\x02\x12\n\n\x06\x41LWAYS\x10\x03\"a\n\x0e\x45ventRulesInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.monitoring.v1.EventRuleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"]\n\x12\x45ventRuleStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa3\x08\n\tEventRule\x12\x8b\x01\n\x06\x63reate\x12\x32.spaceone.api.monitoring.v1.CreateEventRuleRequest\x1a).spaceone.api.monitoring.v1.EventRuleInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/monitoring/v1/event-rules\x12\x9a\x01\n\x06update\x12\x32.spaceone.api.monitoring.v1.UpdateEventRuleRequest\x1a).spaceone.api.monitoring.v1.EventRuleInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/monitoring/v1/event-rule/{event_rule_id}\x12\xab\x01\n\x0c\x63hange_order\x12\x37.spaceone.api.monitoring.v1.ChangeEventRuleOrderRequest\x1a).spaceone.api.monitoring.v1.EventRuleInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//monitoring/v1/event-rule/{event_rule_id}/order\x12\x81\x01\n\x06\x64\x65lete\x12,.spaceone.api.monitoring.v1.EventRuleRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+*)/monitoring/v1/event-rule/{event_rule_id}\x12\x94\x01\n\x03get\x12/.spaceone.api.monitoring.v1.GetEventRuleRequest\x1a).spaceone.api.monitoring.v1.EventRuleInfo\"1\x82\xd3\xe4\x93\x02+\x12)/monitoring/v1/event-rule/{event_rule_id}\x12\xa7\x01\n\x04list\x12*.spaceone.api.monitoring.v1.EventRuleQuery\x1a*.spaceone.api.monitoring.v1.EventRulesInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/monitoring/v1/event-rulesZ#\"!/monitoring/v1/event-rules/search\x12x\n\x04stat\x12..spaceone.api.monitoring.v1.EventRuleStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/monitoring/v1/event-rules/statb\x06proto3')



_EVENTRULECONDITION = DESCRIPTOR.message_types_by_name['EventRuleCondition']
_EVENTRULEACTIONRESPONDER = DESCRIPTOR.message_types_by_name['EventRuleActionResponder']
_MATCHRULE = DESCRIPTOR.message_types_by_name['MatchRule']
_EVENTRULEACTIONS = DESCRIPTOR.message_types_by_name['EventRuleActions']
_EVENTRULEOPTIONS = DESCRIPTOR.message_types_by_name['EventRuleOptions']
_CREATEEVENTRULEREQUEST = DESCRIPTOR.message_types_by_name['CreateEventRuleRequest']
_UPDATEEVENTRULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateEventRuleRequest']
_CHANGEEVENTRULEORDERREQUEST = DESCRIPTOR.message_types_by_name['ChangeEventRuleOrderRequest']
_EVENTRULEREQUEST = DESCRIPTOR.message_types_by_name['EventRuleRequest']
_GETEVENTRULEREQUEST = DESCRIPTOR.message_types_by_name['GetEventRuleRequest']
_EVENTRULEQUERY = DESCRIPTOR.message_types_by_name['EventRuleQuery']
_EVENTRULEINFO = DESCRIPTOR.message_types_by_name['EventRuleInfo']
_EVENTRULESINFO = DESCRIPTOR.message_types_by_name['EventRulesInfo']
_EVENTRULESTATQUERY = DESCRIPTOR.message_types_by_name['EventRuleStatQuery']
_CREATEEVENTRULEREQUEST_CONDITIONSPOLICY = _CREATEEVENTRULEREQUEST.enum_types_by_name['ConditionsPolicy']
_UPDATEEVENTRULEREQUEST_CONDITIONSPOLICY = _UPDATEEVENTRULEREQUEST.enum_types_by_name['ConditionsPolicy']
_EVENTRULEQUERY_EVENTRULESCOPE = _EVENTRULEQUERY.enum_types_by_name['EventRuleScope']
_EVENTRULEINFO_EVENTRULESCOPE = _EVENTRULEINFO.enum_types_by_name['EventRuleScope']
_EVENTRULEINFO_CONDITIONSPOLICY = _EVENTRULEINFO.enum_types_by_name['ConditionsPolicy']
EventRuleCondition = _reflection.GeneratedProtocolMessageType('EventRuleCondition', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULECONDITION,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleCondition)
  })
_sym_db.RegisterMessage(EventRuleCondition)

EventRuleActionResponder = _reflection.GeneratedProtocolMessageType('EventRuleActionResponder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULEACTIONRESPONDER,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleActionResponder)
  })
_sym_db.RegisterMessage(EventRuleActionResponder)

MatchRule = _reflection.GeneratedProtocolMessageType('MatchRule', (_message.Message,), {
  'DESCRIPTOR' : _MATCHRULE,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MatchRule)
  })
_sym_db.RegisterMessage(MatchRule)

EventRuleActions = _reflection.GeneratedProtocolMessageType('EventRuleActions', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULEACTIONS,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleActions)
  })
_sym_db.RegisterMessage(EventRuleActions)

EventRuleOptions = _reflection.GeneratedProtocolMessageType('EventRuleOptions', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULEOPTIONS,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleOptions)
  })
_sym_db.RegisterMessage(EventRuleOptions)

CreateEventRuleRequest = _reflection.GeneratedProtocolMessageType('CreateEventRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTRULEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateEventRuleRequest)
  })
_sym_db.RegisterMessage(CreateEventRuleRequest)

UpdateEventRuleRequest = _reflection.GeneratedProtocolMessageType('UpdateEventRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTRULEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateEventRuleRequest)
  })
_sym_db.RegisterMessage(UpdateEventRuleRequest)

ChangeEventRuleOrderRequest = _reflection.GeneratedProtocolMessageType('ChangeEventRuleOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEEVENTRULEORDERREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ChangeEventRuleOrderRequest)
  })
_sym_db.RegisterMessage(ChangeEventRuleOrderRequest)

EventRuleRequest = _reflection.GeneratedProtocolMessageType('EventRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleRequest)
  })
_sym_db.RegisterMessage(EventRuleRequest)

GetEventRuleRequest = _reflection.GeneratedProtocolMessageType('GetEventRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTRULEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetEventRuleRequest)
  })
_sym_db.RegisterMessage(GetEventRuleRequest)

EventRuleQuery = _reflection.GeneratedProtocolMessageType('EventRuleQuery', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULEQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleQuery)
  })
_sym_db.RegisterMessage(EventRuleQuery)

EventRuleInfo = _reflection.GeneratedProtocolMessageType('EventRuleInfo', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULEINFO,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleInfo)
  })
_sym_db.RegisterMessage(EventRuleInfo)

EventRulesInfo = _reflection.GeneratedProtocolMessageType('EventRulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULESINFO,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRulesInfo)
  })
_sym_db.RegisterMessage(EventRulesInfo)

EventRuleStatQuery = _reflection.GeneratedProtocolMessageType('EventRuleStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRULESTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.event_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventRuleStatQuery)
  })
_sym_db.RegisterMessage(EventRuleStatQuery)

_EVENTRULE = DESCRIPTOR.services_by_name['EventRule']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EVENTRULE.methods_by_name['create']._options = None
  _EVENTRULE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/monitoring/v1/event-rules'
  _EVENTRULE.methods_by_name['update']._options = None
  _EVENTRULE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002+\032)/monitoring/v1/event-rule/{event_rule_id}'
  _EVENTRULE.methods_by_name['change_order']._options = None
  _EVENTRULE.methods_by_name['change_order']._serialized_options = b'\202\323\344\223\0021\032//monitoring/v1/event-rule/{event_rule_id}/order'
  _EVENTRULE.methods_by_name['delete']._options = None
  _EVENTRULE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002+*)/monitoring/v1/event-rule/{event_rule_id}'
  _EVENTRULE.methods_by_name['get']._options = None
  _EVENTRULE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002+\022)/monitoring/v1/event-rule/{event_rule_id}'
  _EVENTRULE.methods_by_name['list']._options = None
  _EVENTRULE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/monitoring/v1/event-rulesZ#\"!/monitoring/v1/event-rules/search'
  _EVENTRULE.methods_by_name['stat']._options = None
  _EVENTRULE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002!\"\037/monitoring/v1/event-rules/stat'
  _EVENTRULECONDITION._serialized_start=198
  _EVENTRULECONDITION._serialized_end=264
  _EVENTRULEACTIONRESPONDER._serialized_start=266
  _EVENTRULEACTIONRESPONDER._serialized_end=336
  _MATCHRULE._serialized_start=338
  _MATCHRULE._serialized_end=381
  _EVENTRULEACTIONS._serialized_start=384
  _EVENTRULEACTIONS._serialized_end=733
  _EVENTRULEOPTIONS._serialized_start=735
  _EVENTRULEOPTIONS._serialized_end=778
  _CREATEEVENTRULEREQUEST._serialized_start=781
  _CREATEEVENTRULEREQUEST._serialized_end=1247
  _CREATEEVENTRULEREQUEST_CONDITIONSPOLICY._serialized_start=1189
  _CREATEEVENTRULEREQUEST_CONDITIONSPOLICY._serialized_end=1247
  _UPDATEEVENTRULEREQUEST._serialized_start=1250
  _UPDATEEVENTRULEREQUEST._serialized_end=1719
  _UPDATEEVENTRULEREQUEST_CONDITIONSPOLICY._serialized_start=1189
  _UPDATEEVENTRULEREQUEST_CONDITIONSPOLICY._serialized_end=1247
  _CHANGEEVENTRULEORDERREQUEST._serialized_start=1721
  _CHANGEEVENTRULEORDERREQUEST._serialized_end=1807
  _EVENTRULEREQUEST._serialized_start=1809
  _EVENTRULEREQUEST._serialized_end=1869
  _GETEVENTRULEREQUEST._serialized_start=1871
  _GETEVENTRULEREQUEST._serialized_end=1948
  _EVENTRULEQUERY._serialized_start=1951
  _EVENTRULEQUERY._serialized_end=2220
  _EVENTRULEQUERY_EVENTRULESCOPE._serialized_start=2163
  _EVENTRULEQUERY_EVENTRULESCOPE._serialized_end=2220
  _EVENTRULEINFO._serialized_start=2223
  _EVENTRULEINFO._serialized_end=2861
  _EVENTRULEINFO_EVENTRULESCOPE._serialized_start=2163
  _EVENTRULEINFO_EVENTRULESCOPE._serialized_end=2220
  _EVENTRULEINFO_CONDITIONSPOLICY._serialized_start=1189
  _EVENTRULEINFO_CONDITIONSPOLICY._serialized_end=1247
  _EVENTRULESINFO._serialized_start=2863
  _EVENTRULESINFO._serialized_end=2960
  _EVENTRULESTATQUERY._serialized_start=2962
  _EVENTRULESTATQUERY._serialized_end=3055
  _EVENTRULE._serialized_start=3058
  _EVENTRULE._serialized_end=4117
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/anomaly_cost_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:spaceone/api/cost_analysis/v1/anomaly_cost_detection.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"V\n\x1eGetAnomalyCostDetectionRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12!\n\x19\x61nomaly_cost_detection_id\x18\x02 \x01(\t\"D\n\nSearchData\x12\x12\n\nstart_date\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\"Z\n\x19\x41nomalyCostDetectionQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x9f\x03\n\x18\x41nomalyCostDetectionInfo\x12!\n\x19\x61nomaly_cost_detection_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x0f\n\x07product\x18\x07 \x01(\t\x12\x19\n\x11original_currency\x18\x08 \x01(\t\x12\x14\n\x0csum_usd_cost\x18\t \x01(\x01\x12\x19\n\x11sum_original_cost\x18\n \x01(\x01\x12\x14\n\x0c\x61vg_usd_cost\x18\x0b \x01(\x01\x12\x19\n\x11\x61vg_original_cost\x18\x0c \x01(\x01\x12\x15\n\rexchange_rate\x18\r \x01(\x01\x12\x19\n\x11\x61nomaly_cost_date\x18\x0e \x01(\t\x12\x13\n\x0b\x62illed_date\x18\x0f \x01(\t\x12\x11\n\tbilled_at\x18\x10 \x01(\t\x12\x12\n\ncreated_at\x18\x11 \x01(\t\"z\n\x19\x41nomalyCostDetectionsInfo\x12H\n\x07results\x18\x01 \x03(\x0b\x32\x37.spaceone.api.cost_analysis.v1.AnomalyCostDetectionInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"h\n\x1d\x41nomalyCostDetectionStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x87\x02\n(AnomalyCostDetectionCompareStatDiffQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12<\n\tpast_data\x18\x03 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.SearchData\x12?\n\x0c\x63urrent_data\x18\x04 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.SearchData\x12\x13\n\x0bsearch_type\x18\x05 \x01(\t2\xc3\x05\n\x14\x41nomalyCostDetection\x12\xaf\x01\n\x03get\x12=.spaceone.api.cost_analysis.v1.GetAnomalyCostDetectionRequest\x1a\x37.spaceone.api.cost_analysis.v1.AnomalyCostDetectionInfo\"0\x82\xd3\xe4\x93\x02*\"(/inventory/v1/anomaly-cost-detection/get\x12\xad\x01\n\x04list\x12\x38.spaceone.api.cost_analysis.v1.AnomalyCostDetectionQuery\x1a\x38.spaceone.api.cost_analysis.v1.AnomalyCostDetectionsInfo\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/anomaly-cost-detection/list\x12\x90\x01\n\x04stat\x12<.spaceone.api.cost_analysis.v1.AnomalyCostDetectionStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/anomaly-cost-detection/stat\x12\xb5\x01\n\x11\x63ompare_stat_diff\x12G.spaceone.api.cost_analysis.v1.AnomalyCostDetectionCompareStatDiffQuery\x1a\x17.google.protobuf.Struct\">\x82\xd3\xe4\x93\x02\x38\"6/inventory/v1/anomaly-cost-detection/compare-stat-diffb\x06proto3')



_GETANOMALYCOSTDETECTIONREQUEST = DESCRIPTOR.message_types_by_name['GetAnomalyCostDetectionRequest']
_SEARCHDATA = DESCRIPTOR.message_types_by_name['SearchData']
_ANOMALYCOSTDETECTIONQUERY = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionQuery']
_ANOMALYCOSTDETECTIONINFO = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionInfo']
_ANOMALYCOSTDETECTIONSINFO = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionsInfo']
_ANOMALYCOSTDETECTIONSTATQUERY = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionStatQuery']
_ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionCompareStatDiffQuery']
GetAnomalyCostDetectionRequest = _reflection.GeneratedProtocolMessageType('GetAnomalyCostDetectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETANOMALYCOSTDETECTIONREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetAnomalyCostDetectionRequest)
  })
_sym_db.RegisterMessage(GetAnomalyCostDetectionRequest)

SearchData = _reflection.GeneratedProtocolMessageType('SearchData', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHDATA,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SearchData)
  })
_sym_db.RegisterMessage(SearchData)

AnomalyCostDetectionQuery = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionQuery', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionQuery)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionQuery)

AnomalyCostDetectionInfo = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionInfo)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionInfo)

AnomalyCostDetectionsInfo = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionsInfo)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionsInfo)

AnomalyCostDetectionStatQuery = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionStatQuery)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionStatQuery)

AnomalyCostDetectionCompareStatDiffQuery = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionCompareStatDiffQuery', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionCompareStatDiffQuery)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionCompareStatDiffQuery)

_ANOMALYCOSTDETECTION = DESCRIPTOR.services_by_name['AnomalyCostDetection']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['get']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['get']._serialized_options = b'\202\323\344\223\002*\"(/inventory/v1/anomaly-cost-detection/get'
  _ANOMALYCOSTDETECTION.methods_by_name['list']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['list']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/anomaly-cost-detection/list'
  _ANOMALYCOSTDETECTION.methods_by_name['stat']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/anomaly-cost-detection/stat'
  _ANOMALYCOSTDETECTION.methods_by_name['compare_stat_diff']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['compare_stat_diff']._serialized_options = b'\202\323\344\223\0028\"6/inventory/v1/anomaly-cost-detection/compare-stat-diff'
  _GETANOMALYCOSTDETECTIONREQUEST._serialized_start=187
  _GETANOMALYCOSTDETECTIONREQUEST._serialized_end=273
  _SEARCHDATA._serialized_start=275
  _SEARCHDATA._serialized_end=343
  _ANOMALYCOSTDETECTIONQUERY._serialized_start=345
  _ANOMALYCOSTDETECTIONQUERY._serialized_end=435
  _ANOMALYCOSTDETECTIONINFO._serialized_start=438
  _ANOMALYCOSTDETECTIONINFO._serialized_end=853
  _ANOMALYCOSTDETECTIONSINFO._serialized_start=855
  _ANOMALYCOSTDETECTIONSINFO._serialized_end=977
  _ANOMALYCOSTDETECTIONSTATQUERY._serialized_start=979
  _ANOMALYCOSTDETECTIONSTATQUERY._serialized_end=1083
  _ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY._serialized_start=1086
  _ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY._serialized_end=1349
  _ANOMALYCOSTDETECTION._serialized_start=1352
  _ANOMALYCOSTDETECTION._serialized_end=2059
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/budget_usage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/cost_analysis/v1/budget_usage.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x80\x01\n\x10\x42udgetUsageQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tbudget_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xb5\x01\n\x0f\x42udgetUsageInfo\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x10\n\x08usd_cost\x18\x05 \x01(\x02\x12\r\n\x05limit\x18\x06 \x01(\x02\x12+\n\ncost_types\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x15 \x01(\t\"h\n\x10\x42udgetUsagesInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.cost_analysis.v1.BudgetUsageInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14\x42udgetUsageStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf1\x02\n\x0b\x42udgetUsage\x12\xd1\x01\n\x04list\x12/.spaceone.api.cost_analysis.v1.BudgetUsageQuery\x1a/.spaceone.api.cost_analysis.v1.BudgetUsagesInfo\"g\x82\xd3\xe4\x93\x02\x61\x12*/cost-analysis/v1/budget/{budget_id}/usageZ3\"1/cost-analysis/v1/budget/{budget_id}/usage/search\x12\x8d\x01\n\x04stat\x12\x33.spaceone.api.cost_analysis.v1.BudgetUsageStatQuery\x1a\x17.google.protobuf.Struct\"7\x82\xd3\xe4\x93\x02\x31\"//cost-analysis/v1/budget/{budget_id}/usage/statb\x06proto3')



_BUDGETUSAGEQUERY = DESCRIPTOR.message_types_by_name['BudgetUsageQuery']
_BUDGETUSAGEINFO = DESCRIPTOR.message_types_by_name['BudgetUsageInfo']
_BUDGETUSAGESINFO = DESCRIPTOR.message_types_by_name['BudgetUsagesInfo']
_BUDGETUSAGESTATQUERY = DESCRIPTOR.message_types_by_name['BudgetUsageStatQuery']
BudgetUsageQuery = _reflection.GeneratedProtocolMessageType('BudgetUsageQuery', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETUSAGEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetUsageQuery)
  })
_sym_db.RegisterMessage(BudgetUsageQuery)

BudgetUsageInfo = _reflection.GeneratedProtocolMessageType('BudgetUsageInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETUSAGEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetUsageInfo)
  })
_sym_db.RegisterMessage(BudgetUsageInfo)

BudgetUsagesInfo = _reflection.GeneratedProtocolMessageType('BudgetUsagesInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETUSAGESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetUsagesInfo)
  })
_sym_db.RegisterMessage(BudgetUsagesInfo)

BudgetUsageStatQuery = _reflection.GeneratedProtocolMessageType('BudgetUsageStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETUSAGESTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetUsageStatQuery)
  })
_sym_db.RegisterMessage(BudgetUsageStatQuery)

_BUDGETUSAGE = DESCRIPTOR.services_by_name['BudgetUsage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUDGETUSAGE.methods_by_name['list']._options = None
  _BUDGETUSAGE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002a\022*/cost-analysis/v1/budget/{budget_id}/usageZ3\"1/cost-analysis/v1/budget/{budget_id}/usage/search'
  _BUDGETUSAGE.methods_by_name['stat']._options = None
  _BUDGETUSAGE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\0021\"//cost-analysis/v1/budget/{budget_id}/usage/stat'
  _BUDGETUSAGEQUERY._serialized_start=178
  _BUDGETUSAGEQUERY._serialized_end=306
  _BUDGETUSAGEINFO._serialized_start=309
  _BUDGETUSAGEINFO._serialized_end=490
  _BUDGETUSAGESINFO._serialized_start=492
  _BUDGETUSAGESINFO._serialized_end=596
  _BUDGETUSAGESTATQUERY._serialized_start=598
  _BUDGETUSAGESTATQUERY._serialized_end=693
  _BUDGETUSAGE._serialized_start=696
  _BUDGETUSAGE._serialized_end=1065
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/escalation_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/monitoring/v1/escalation_policy.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xe5\x01\n\x14\x45scalationPolicyRule\x12^\n\x12notification_level\x18\x01 \x01(\x0e\x32\x42.spaceone.api.monitoring.v1.EscalationPolicyRule.NotificationLevel\x12\x18\n\x10\x65scalate_minutes\x18\x02 \x01(\x05\"S\n\x11NotificationLevel\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"\x88\x03\n\x1d\x43reateEscalationPolicyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x05rules\x18\x02 \x03(\x0b\x32\x30.spaceone.api.monitoring.v1.EscalationPolicyRule\x12\x14\n\x0crepeat_count\x18\x03 \x01(\x05\x12m\n\x10\x66inish_condition\x18\x04 \x01(\x0e\x32S.spaceone.api.monitoring.v1.CreateEscalationPolicyRequest.EscalationFinishCondition\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"E\n\x19\x45scalationFinishCondition\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x01\x12\x0c\n\x08RESOLVED\x10\x02\"\x92\x03\n\x1dUpdateEscalationPolicyRequest\x12\x1c\n\x14\x65scalation_policy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12?\n\x05rules\x18\x03 \x03(\x0b\x32\x30.spaceone.api.monitoring.v1.EscalationPolicyRule\x12\x14\n\x0crepeat_count\x18\x04 \x01(\x05\x12m\n\x10\x66inish_condition\x18\x05 \x01(\x0e\x32S.spaceone.api.monitoring.v1.UpdateEscalationPolicyRequest.EscalationFinishCondition\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"E\n\x19\x45scalationFinishCondition\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x01\x12\x0c\n\x08RESOLVED\x10\x02\"J\n\x17\x45scalationPolicyRequest\x12\x1c\n\x14\x65scalation_policy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"[\n\x1aGetEscalationPolicyRequest\x12\x1c\n\x14\x65scalation_policy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xf2\x03\n\x15\x45scalationPolicyQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1c\n\x14\x65scalation_policy_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nis_default\x18\x04 \x01(\x08\x12\x65\n\x10\x66inish_condition\x18\x05 \x01(\x0e\x32K.spaceone.api.monitoring.v1.EscalationPolicyQuery.EscalationFinishCondition\x12V\n\x05scope\x18\x06 \x01(\x0e\x32G.spaceone.api.monitoring.v1.EscalationPolicyQuery.EscalationPolicyScope\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"@\n\x15\x45scalationPolicyScope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06GLOBAL\x10\x01\x12\x0b\n\x07PROJECT\x10\x02\"E\n\x19\x45scalationFinishCondition\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x01\x12\x0c\n\x08RESOLVED\x10\x02\"\xd5\x04\n\x14\x45scalationPolicyInfo\x12\x1c\n\x14\x65scalation_policy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\x12?\n\x05rules\x18\x04 \x03(\x0b\x32\x30.spaceone.api.monitoring.v1.EscalationPolicyRule\x12\x14\n\x0crepeat_count\x18\x05 \x01(\x05\x12\x64\n\x10\x66inish_condition\x18\x06 \x01(\x0e\x32J.spaceone.api.monitoring.v1.EscalationPolicyInfo.EscalationFinishCondition\x12U\n\x05scope\x18\x07 \x01(\x0e\x32\x46.spaceone.api.monitoring.v1.EscalationPolicyInfo.EscalationPolicyScope\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"@\n\x15\x45scalationPolicyScope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06GLOBAL\x10\x01\x12\x0b\n\x07PROJECT\x10\x02\"E\n\x19\x45scalationFinishCondition\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x01\x12\x0c\n\x08RESOLVED\x10\x02\"p\n\x16\x45scalationPoliciesInfo\x12\x41\n\x07results\x18\x01 \x03(\x0b\x32\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"d\n\x19\x45scalationPolicyStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xd2\t\n\x10\x45scalationPolicy\x12\xa1\x01\n\x06\x63reate\x12\x39.spaceone.api.monitoring.v1.CreateEscalationPolicyRequest\x1a\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\"*\x82\xd3\xe4\x93\x02$\"\"/monitoring/v1/escalation-policies\x12\xb6\x01\n\x06update\x12\x39.spaceone.api.monitoring.v1.UpdateEscalationPolicyRequest\x1a\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\"?\x82\xd3\xe4\x93\x02\x39\x1a\x37/monitoring/v1/escalation-policy/{escalation_policy_id}\x12\xc1\x01\n\x0bset_default\x12\x33.spaceone.api.monitoring.v1.EscalationPolicyRequest\x1a\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\"K\x82\xd3\xe4\x93\x02\x45\x1a\x43/monitoring/v1/escalation-policy/{escalation_policy_id}/set-default\x12\x96\x01\n\x06\x64\x65lete\x12\x33.spaceone.api.monitoring.v1.EscalationPolicyRequest\x1a\x16.google.protobuf.Empty\"?\x82\xd3\xe4\x93\x02\x39*7/monitoring/v1/escalation-policy/{escalation_policy_id}\x12\xb0\x01\n\x03get\x12\x36.spaceone.api.monitoring.v1.GetEscalationPolicyRequest\x1a\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/monitoring/v1/escalation-policy/{escalation_policy_id}\x12\xc6\x01\n\x04list\x12\x31.spaceone.api.monitoring.v1.EscalationPolicyQuery\x1a\x32.spaceone.api.monitoring.v1.EscalationPoliciesInfo\"W\x82\xd3\xe4\x93\x02Q\x12\"/monitoring/v1/escalation-policiesZ+\")/monitoring/v1/escalation-policies/search\x12\x87\x01\n\x04stat\x12\x35.spaceone.api.monitoring.v1.EscalationPolicyStatQuery\x1a\x17.google.protobuf.Struct\"/\x82\xd3\xe4\x93\x02)\"\'/monitoring/v1/escalation-policies/statb\x06proto3')



_ESCALATIONPOLICYRULE = DESCRIPTOR.message_types_by_name['EscalationPolicyRule']
_CREATEESCALATIONPOLICYREQUEST = DESCRIPTOR.message_types_by_name['CreateEscalationPolicyRequest']
_UPDATEESCALATIONPOLICYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEscalationPolicyRequest']
_ESCALATIONPOLICYREQUEST = DESCRIPTOR.message_types_by_name['EscalationPolicyRequest']
_GETESCALATIONPOLICYREQUEST = DESCRIPTOR.message_types_by_name['GetEscalationPolicyRequest']
_ESCALATIONPOLICYQUERY = DESCRIPTOR.message_types_by_name['EscalationPolicyQuery']
_ESCALATIONPOLICYINFO = DESCRIPTOR.message_types_by_name['EscalationPolicyInfo']
_ESCALATIONPOLICIESINFO = DESCRIPTOR.message_types_by_name['EscalationPoliciesInfo']
_ESCALATIONPOLICYSTATQUERY = DESCRIPTOR.message_types_by_name['EscalationPolicyStatQuery']
_ESCALATIONPOLICYRULE_NOTIFICATIONLEVEL = _ESCALATIONPOLICYRULE.enum_types_by_name['NotificationLevel']
_CREATEESCALATIONPOLICYREQUEST_ESCALATIONFINISHCONDITION = _CREATEESCALATIONPOLICYREQUEST.enum_types_by_name['EscalationFinishCondition']
_UPDATEESCALATIONPOLICYREQUEST_ESCALATIONFINISHCONDITION = _UPDATEESCALATIONPOLICYREQUEST.enum_types_by_name['EscalationFinishCondition']
_ESCALATIONPOLICYQUERY_ESCALATIONPOLICYSCOPE = _ESCALATIONPOLICYQUERY.enum_types_by_name['EscalationPolicyScope']
_ESCALATIONPOLICYQUERY_ESCALATIONFINISHCONDITION = _ESCALATIONPOLICYQUERY.enum_types_by_name['EscalationFinishCondition']
_ESCALATIONPOLICYINFO_ESCALATIONPOLICYSCOPE = _ESCALATIONPOLICYINFO.enum_types_by_name['EscalationPolicyScope']
_ESCALATIONPOLICYINFO_ESCALATIONFINISHCONDITION = _ESCALATIONPOLICYINFO.enum_types_by_name['EscalationFinishCondition']
EscalationPolicyRule = _reflection.GeneratedProtocolMessageType('EscalationPolicyRule', (_message.Message,), {
  'DESCRIPTOR' : _ESCALATIONPOLICYRULE,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EscalationPolicyRule)
  })
_sym_db.RegisterMessage(EscalationPolicyRule)

CreateEscalationPolicyRequest = _reflection.GeneratedProtocolMessageType('CreateEscalationPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEESCALATIONPOLICYREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateEscalationPolicyRequest)
  })
_sym_db.RegisterMessage(CreateEscalationPolicyRequest)

UpdateEscalationPolicyRequest = _reflection.GeneratedProtocolMessageType('UpdateEscalationPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEESCALATIONPOLICYREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateEscalationPolicyRequest)
  })
_sym_db.RegisterMessage(UpdateEscalationPolicyRequest)

EscalationPolicyRequest = _reflection.GeneratedProtocolMessageType('EscalationPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ESCALATIONPOLICYREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EscalationPolicyRequest)
  })
_sym_db.RegisterMessage(EscalationPolicyRequest)

GetEscalationPolicyRequest = _reflection.GeneratedProtocolMessageType('GetEscalationPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETESCALATIONPOLICYREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetEscalationPolicyRequest)
  })
_sym_db.RegisterMessage(GetEscalationPolicyRequest)

EscalationPolicyQuery = _reflection.GeneratedProtocolMessageType('EscalationPolicyQuery', (_message.Message,), {
  'DESCRIPTOR' : _ESCALATIONPOLICYQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EscalationPolicyQuery)
  })
_sym_db.RegisterMessage(EscalationPolicyQuery)

EscalationPolicyInfo = _reflection.GeneratedProtocolMessageType('EscalationPolicyInfo', (_message.Message,), {
  'DESCRIPTOR' : _ESCALATIONPOLICYINFO,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EscalationPolicyInfo)
  })
_sym_db.RegisterMessage(EscalationPolicyInfo)

EscalationPoliciesInfo = _reflection.GeneratedProtocolMessageType('EscalationPoliciesInfo', (_message.Message,), {
  'DESCRIPTOR' : _ESCALATIONPOLICIESINFO,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EscalationPoliciesInfo)
  })
_sym_db.RegisterMessage(EscalationPoliciesInfo)

EscalationPolicyStatQuery = _reflection.GeneratedProtocolMessageType('EscalationPolicyStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ESCALATIONPOLICYSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.escalation_policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EscalationPolicyStatQuery)
  })
_sym_db.RegisterMessage(EscalationPolicyStatQuery)

_ESCALATIONPOLICY = DESCRIPTOR.services_by_name['EscalationPolicy']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ESCALATIONPOLICY.methods_by_name['create']._options = None
  _ESCALATIONPOLICY.methods_by_name['create']._serialized_options = b'\202\323\344\223\002$\"\"/monitoring/v1/escalation-policies'
  _ESCALATIONPOLICY.methods_by_name['update']._options = None
  _ESCALATIONPOLICY.methods_by_name['update']._serialized_options = b'\202\323\344\223\0029\0327/monitoring/v1/escalation-policy/{escalation_policy_id}'
  _ESCALATIONPOLICY.methods_by_name['set_default']._options = None
  _ESCALATIONPOLICY.methods_by_name['set_default']._serialized_options = b'\202\323\344\223\002E\032C/monitoring/v1/escalation-policy/{escalation_policy_id}/set-default'
  _ESCALATIONPOLICY.methods_by_name['delete']._options = None
  _ESCALATIONPOLICY.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0029*7/monitoring/v1/escalation-policy/{escalation_policy_id}'
  _ESCALATIONPOLICY.methods_by_name['get']._options = None
  _ESCALATIONPOLICY.methods_by_name['get']._serialized_options = b'\202\323\344\223\0029\0227/monitoring/v1/escalation-policy/{escalation_policy_id}'
  _ESCALATIONPOLICY.methods_by_name['list']._options = None
  _ESCALATIONPOLICY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002Q\022\"/monitoring/v1/escalation-policiesZ+\")/monitoring/v1/escalation-policies/search'
  _ESCALATIONPOLICY.methods_by_name['stat']._options = None
  _ESCALATIONPOLICY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002)\"\'/monitoring/v1/escalation-policies/stat'
  _ESCALATIONPOLICYRULE._serialized_start=206
  _ESCALATIONPOLICYRULE._serialized_end=435
  _ESCALATIONPOLICYRULE_NOTIFICATIONLEVEL._serialized_start=352
  _ESCALATIONPOLICYRULE_NOTIFICATIONLEVEL._serialized_end=435
  _CREATEESCALATIONPOLICYREQUEST._serialized_start=438
  _CREATEESCALATIONPOLICYREQUEST._serialized_end=830
  _CREATEESCALATIONPOLICYREQUEST_ESCALATIONFINISHCONDITION._serialized_start=761
  _CREATEESCALATIONPOLICYREQUEST_ESCALATIONFINISHCONDITION._serialized_end=830
  _UPDATEESCALATIONPOLICYREQUEST._serialized_start=833
  _UPDATEESCALATIONPOLICYREQUEST._serialized_end=1235
  _UPDATEESCALATIONPOLICYREQUEST_ESCALATIONFINISHCONDITION._serialized_start=761
  _UPDATEESCALATIONPOLICYREQUEST_ESCALATIONFINISHCONDITION._serialized_end=830
  _ESCALATIONPOLICYREQUEST._serialized_start=1237
  _ESCALATIONPOLICYREQUEST._serialized_end=1311
  _GETESCALATIONPOLICYREQUEST._serialized_start=1313
  _GETESCALATIONPOLICYREQUEST._serialized_end=1404
  _ESCALATIONPOLICYQUERY._serialized_start=1407
  _ESCALATIONPOLICYQUERY._serialized_end=1905
  _ESCALATIONPOLICYQUERY_ESCALATIONPOLICYSCOPE._serialized_start=1770
  _ESCALATIONPOLICYQUERY_ESCALATIONPOLICYSCOPE._serialized_end=1834
  _ESCALATIONPOLICYQUERY_ESCALATIONFINISHCONDITION._serialized_start=761
  _ESCALATIONPOLICYQUERY_ESCALATIONFINISHCONDITION._serialized_end=830
  _ESCALATIONPOLICYINFO._serialized_start=1908
  _ESCALATIONPOLICYINFO._serialized_end=2505
  _ESCALATIONPOLICYINFO_ESCALATIONPOLICYSCOPE._serialized_start=1770
  _ESCALATIONPOLICYINFO_ESCALATIONPOLICYSCOPE._serialized_end=1834
  _ESCALATIONPOLICYINFO_ESCALATIONFINISHCONDITION._serialized_start=761
  _ESCALATIONPOLICYINFO_ESCALATIONFINISHCONDITION._serialized_end=830
  _ESCALATIONPOLICIESINFO._serialized_start=2507
  _ESCALATIONPOLICIESINFO._serialized_end=2619
  _ESCALATIONPOLICYSTATQUERY._serialized_start=2621
  _ESCALATIONPOLICYSTATQUERY._serialized_end=2721
  _ESCALATIONPOLICY._serialized_start=2724
  _ESCALATIONPOLICY._serialized_end=3958
# @@protoc_insertion_point(module_scope)
